@@ -1,11 +1,10 @@
-import dummy_autoupdate
-import importlib
+
 import sys
 import site
 
 
 def main():
-    global dummy_autoupdate
+    import dummy_autoupdate
     reboot_code = dummy_autoupdate.MainWindow.EXIT_CODE_REBOOT
     exit_code = dummy_autoupdate.run()
 
